@@ -66,9 +66,12 @@ extern pid_t wait_pid_nohang (pid_t, int *) ;
 extern int wait_pids_nohang (pid_t const *, unsigned int, int *) ;
 #define wait_status(w) (WIFSIGNALED(w) ? 256 + WTERMSIG(w) : WEXITSTATUS(w))
 #define wait_estatus(w) (WIFSIGNALED(w) ? 128 + WTERMSIG(w) : WEXITSTATUS(w) >= 128 ? 128 : WEXITSTATUS(w))
+
 extern unsigned int wait_reap (void) ;
 extern int waitn (pid_t *, unsigned int) ;
+extern int waitn_posix (pid_t *, unsigned int, int *) ;
 extern int waitn_reap (pid_t *, unsigned int) ;
+extern int waitn_reap_posix (pid_t *, unsigned int, int *) ;
 
 extern int fd_chdir (int) ;
 
@@ -81,6 +84,7 @@ extern int sagethostname (stralloc *) ;
 
 extern int slurp (stralloc *, int) ;
 extern int openslurpclose (stralloc *, char const *) ;
+extern ssize_t readnclose (int fd, char *, size_t) ;  /* closes fd */
 extern ssize_t openreadnclose (char const *, char *, size_t) ;
 extern ssize_t openreadnclose_nb (char const *, char *, size_t) ;
 extern int openreadfileclose (char const *, stralloc *, size_t) ;
